@@ -145,7 +145,7 @@ Notes
 
 References
 ----------
-.. [1]  **Wyszecki & Stiles**,
+.. [2]  **Wyszecki & Stiles**,
         *Color Science - Concepts and Methods Data and Formulae -
         Second Edition*,
         Wiley Classics Library Edition, published 2000, ISBN-10: 0-471-39918-3,
@@ -288,8 +288,9 @@ def uv_to_CCT_ohno2013(uv,
 
     References
     ----------
-    .. [2]  **Yoshi Ohno**, `Practical Use and Calculation of CCT and Duv
-            <http://dx.doi.org/10.1080/15502724.2014.839020>`_
+    .. [3]  **Yoshi Ohno**, `Practical Use and Calculation of CCT and Duv
+            <http://dx.doi.org/10.1080/15502724.2014.839020>`_,
+            DOI: http://dx.doi.org/10.1080/15502724.2014.839020
 
     Examples
     --------
@@ -379,8 +380,9 @@ def CCT_to_uv_ohno2013(CCT,
 
     References
     ----------
-    .. [3]  **Yoshi Ohno**, `Practical Use and Calculation of CCT and Duv
-            <http://dx.doi.org/10.1080/15502724.2014.839020>`_
+    .. [4]  **Yoshi Ohno**, `Practical Use and Calculation of CCT and Duv
+            <http://dx.doi.org/10.1080/15502724.2014.839020>`_,
+            DOI: http://dx.doi.org/10.1080/15502724.2014.839020
 
     Examples
     --------
@@ -438,13 +440,13 @@ def uv_to_CCT_robertson1968(uv):
 
     References
     ----------
-    .. [4]  **Wyszecki & Stiles**,
+    .. [5]  **Wyszecki & Stiles**,
             *Color Science - Concepts and Methods Data and Formulae -
             Second Edition*,
             Wiley Classics Library Edition, published 2000,
             ISBN-10: 0-471-39918-3,
             page  227.
-    .. [5]  *Adobe DNG SDK 1.3.0.0*:
+    .. [6]  *Adobe DNG SDK 1.3.0.0*:
             *dng_sdk_1_3/dng_sdk/source/dng_temperature.cpp*:
             *dng_temperature::Set_xy_coord*.
 
@@ -531,15 +533,16 @@ def CCT_to_uv_robertson1968(CCT, Duv=0):
 
     References
     ----------
-    .. [6]  **Wyszecki & Stiles**,
+    .. [7]  **Wyszecki & Stiles**,
             *Color Science - Concepts and Methods Data and Formulae -
             Second Edition*,
             Wiley Classics Library Edition, published 2000,
             ISBN-10: 0-471-39918-3,
             page  227.
-    .. [7]  *Adobe DNG SDK 1.3.0.0*:
+    .. [8]  *Adobe DNG SDK 1.3.0.0*:
             *dng_sdk_1_3/dng_sdk/source/dng_temperature.cpp*:
             *dng_temperature::xy_coord*.
+
     Examples
     --------
     >>> CCT = 6500.0081378199056
@@ -742,7 +745,7 @@ def xy_to_CCT_mccamy1992(xy):
 
     References
     ----------
-    .. [8]  http://en.wikipedia.org/wiki/Color_temperature#Approximation
+    .. [9]  http://en.wikipedia.org/wiki/Color_temperature#Approximation
             (Last accessed 28 June 2014)
 
     Examples
@@ -777,9 +780,10 @@ def xy_to_CCT_hernandez1999(xy):
 
     References
     ----------
-    .. [9]  `Calculating correlated color temperatures across the entire gamut
+    .. [10]  `Calculating correlated color temperatures across the entire gamut
             of daylight and skylight chromaticities
-            <http://www.ugr.es/~colorimg/pdfs/ao_1999_5703.pdf>`_
+            <http://www.ugr.es/~colorimg/pdfs/ao_1999_5703.pdf>`_,
+            DOI: http://dx.doi.org/10.1364/AO.38.005703
 
     Examples
     --------
@@ -827,7 +831,7 @@ def CCT_to_xy_kang2002(CCT):
 
     References
     ----------
-    .. [10] `Design of Advanced Color -
+    .. [11] `Design of Advanced Color -
             Temperature Control System for HDTV Applications
             <http://icpr.snu.ac.kr/resource/wop.pdf/J01/2002/041/R06/J012002041R060865.pdf>`_  # noqa
 
@@ -893,12 +897,13 @@ def CCT_to_xy_illuminant_D(CCT):
 
     References
     ----------
-    .. [11] **Wyszecki & Stiles**,
+    .. [12] **Wyszecki & Stiles**,
             *Color Science - Concepts and Methods Data and Formulae -
             Second Edition*,
             Wiley Classics Library Edition, published 2000,
             ISBN-10: 0-471-39918-3,
             page  145.
+
     Examples
     --------
     >>> CCT_to_xy_illuminant_D(6504.38938305)  # doctest: +ELLIPSIS
